import { Balance, ExtrinsicEra, Hash, Index } from '../../../interfaces/runtime';
import { ExtrinsicPayloadValue, IKeyringPair, InterfaceTypes } from '../../../types';
import Compact from '../../../codec/Compact';
import Struct from '../../../codec/Struct';
import Bytes from '../../../primitive/Bytes';
import u32 from '../../../primitive/U32';
export declare const SignedPayloadDefV3: Record<string, InterfaceTypes>;
/**
 * @name ExtrinsicPayloadV3
 * @description
 * A signing payload for an [[Extrinsic]]. For the final encoding, it is variable length based
 * on the contents included
 */
export default class ExtrinsicPayloadV3 extends Struct {
    constructor(value?: ExtrinsicPayloadValue | Uint8Array | string);
    /**
     * @description The block [[Hash]] the signature applies to (mortal/immortal)
     */
    readonly blockHash: Hash;
    /**
     * @description The [[ExtrinsicEra]]
     */
    readonly era: ExtrinsicEra;
    /**
     * @description The genesis [[Hash]] the signature applies to (mortal/immortal)
     */
    readonly genesisHash: Hash;
    /**
     * @description The [[Bytes]] contained in the payload
     */
    readonly method: Bytes;
    /**
     * @description The [[Index]]
     */
    readonly nonce: Compact<Index>;
    /**
     * @description The specVersion for this signature
     */
    readonly specVersion: u32;
    /**
     * @description The tip [[Balance]]
     */
    readonly tip: Compact<Balance>;
    /**
     * @description Sign the payload with the keypair
     */
    sign(signerPair: IKeyringPair): Uint8Array;
}
